@@ -2,29 +2,31 @@ package Mojolicious::Plugin::Proxy;
 
 use base 'Mojolicious::Plugin';
 
-our $VERSION='0.4';
+our $VERSION = '0.6';
 
 sub register {
-  my ($self,$app) = @_;
-     
-     
+  my ($self, $app) = @_;
+
+
   $app->helper(
     proxy_to => sub {
-      my $c = shift;
-      my $url = Mojo::URL->new(shift);
-      my %args = @_ ;
-      $url->query($c->req->params) 
-      if($args{with_query_params});
+      my $c    = shift;
+      my $url  = Mojo::URL->new(shift);
+      my %args = @_;
+      $url->query($c->req->params) if ($args{with_query_params});
 
-      if(Mojo::IOLoop->is_running) {
+      if (Mojo::IOLoop->is_running) {
         $c->render_later;
-        $c->ua->get($url, sub {
-          my ($self, $tx) = @_;
-          _proxy_tx($c, $tx);
-          });
+        $c->ua->get(
+          $url,
+          sub {
+            my ($self, $tx) = @_;
+            _proxy_tx($c, $tx);
+          }
+        );
       }
       else {
-        my $tx=$c->ua->get($url);
+        my $tx = $c->ua->get($url);
         _proxy_tx($c, $tx);
       }
     }
@@ -32,18 +34,16 @@ sub register {
 }
 
 sub _proxy_tx {
-  my ($self,$tx)=@_;
-  if (my $res=$tx->success) {
+  my ($self, $tx) = @_;
+  if (my $res = $tx->success) {
     $self->tx->res($res);
     $self->rendered;
   }
   else {
-    my ($msg,$error) = $tx->error;
-    $self->tx->res->headers->add('X-Remote-Status',$error.': '.$msg);	
-    $self->render(
-        status => 500,
-        text => 'Failed to fetch data from backend'
-    );
+    my $error = $tx->error;
+    $self->tx->res->headers->add('X-Remote-Status',
+      $error->{code} . ': ' . $error->{message});
+    $self->render(status => 500, text => 'Failed to fetch data from backend');
   }
 }
 
